poff [![Build Status](https://travis-ci.org/thusoy/poff.png)](https://travis-ci.org/thusoy/poff)
====

A plain old flask frontend for PowerDNS.

[Test coverage](https://thusoy.github.io/poff)

Development
-----------

Set up local virtualenv with the dependencies:

    $ ./configure

Run the tests:

    $ ./test

Happy hacking!
